@@ -26,18 +26,18 @@ static char *uwsgi_fifo_by_slot() {
 
 #define announce_fifo uwsgi_log_verbose("active master fifo is now %s\n", uwsgi_fifo_by_slot())
 
-static void uwsgi_fifo_set_slot_zero() { uwsgi.master_fifo_slot = 0; announce_fifo; }
-static void uwsgi_fifo_set_slot_one() { uwsgi.master_fifo_slot = 1; announce_fifo; }
-static void uwsgi_fifo_set_slot_two() { uwsgi.master_fifo_slot = 2; announce_fifo; }
-static void uwsgi_fifo_set_slot_three() { uwsgi.master_fifo_slot = 3; announce_fifo; }
-static void uwsgi_fifo_set_slot_four() { uwsgi.master_fifo_slot = 4; announce_fifo; }
-static void uwsgi_fifo_set_slot_five() { uwsgi.master_fifo_slot = 5; announce_fifo; }
-static void uwsgi_fifo_set_slot_six() { uwsgi.master_fifo_slot = 6; announce_fifo; }
-static void uwsgi_fifo_set_slot_seven() { uwsgi.master_fifo_slot = 7; announce_fifo; }
-static void uwsgi_fifo_set_slot_eight() { uwsgi.master_fifo_slot = 8; announce_fifo; }
-static void uwsgi_fifo_set_slot_nine() { uwsgi.master_fifo_slot = 9; announce_fifo; }
+static void uwsgi_fifo_set_slot_zero(int signum) { uwsgi.master_fifo_slot = 0; announce_fifo; }
+static void uwsgi_fifo_set_slot_one(int signum) { uwsgi.master_fifo_slot = 1; announce_fifo; }
+static void uwsgi_fifo_set_slot_two(int signum) { uwsgi.master_fifo_slot = 2; announce_fifo; }
+static void uwsgi_fifo_set_slot_three(int signum) { uwsgi.master_fifo_slot = 3; announce_fifo; }
+static void uwsgi_fifo_set_slot_four(int signum) { uwsgi.master_fifo_slot = 4; announce_fifo; }
+static void uwsgi_fifo_set_slot_five(int signum) { uwsgi.master_fifo_slot = 5; announce_fifo; }
+static void uwsgi_fifo_set_slot_six(int signum) { uwsgi.master_fifo_slot = 6; announce_fifo; }
+static void uwsgi_fifo_set_slot_seven(int signum) { uwsgi.master_fifo_slot = 7; announce_fifo; }
+static void uwsgi_fifo_set_slot_eight(int signum) { uwsgi.master_fifo_slot = 8; announce_fifo; }
+static void uwsgi_fifo_set_slot_nine(int signum) { uwsgi.master_fifo_slot = 9; announce_fifo; }
 
-static void subscriptions_blocker() {
+static void subscriptions_blocker(int signum) {
 	if (uwsgi.subscriptions_blocked) {
 		uwsgi_log_verbose("subscriptions re-enabled\n");
 		uwsgi.subscriptions_blocked = 0;
@@ -48,7 +48,7 @@ static void subscriptions_blocker() {
 	}
 }
 
-static void emperor_rescan() {
+static void emperor_rescan(int signum) {
 	if (uwsgi.emperor_pid > 0) {
 		if (kill(uwsgi.emperor_pid, SIGWINCH)) {
 			uwsgi_error("emperor_rescan()/kill()");
@@ -78,25 +78,25 @@ void uwsgi_master_fifo_prepare() {
 	uwsgi_fifo_table['8'] = uwsgi_fifo_set_slot_eight;
 	uwsgi_fifo_table['9'] = uwsgi_fifo_set_slot_nine;
 
-	uwsgi_fifo_table['-'] = uwsgi_cheaper_decrease;
-	uwsgi_fifo_table['+'] = uwsgi_cheaper_increase;
-	uwsgi_fifo_table['B'] = vassal_sos; 
-	uwsgi_fifo_table['c'] = uwsgi_chain_reload;
-	uwsgi_fifo_table['C'] = uwsgi_go_cheap;
+	uwsgi_fifo_table['-'] = (void (*)(int))uwsgi_cheaper_decrease;
+	uwsgi_fifo_table['+'] = (void (*)(int))uwsgi_cheaper_increase;
+	uwsgi_fifo_table['B'] = (void (*)(int))vassal_sos;
+	uwsgi_fifo_table['c'] = (void (*)(int))uwsgi_chain_reload;
+	uwsgi_fifo_table['C'] = (void (*)(int))uwsgi_go_cheap;
 	uwsgi_fifo_table['E'] = emperor_rescan;
-	uwsgi_fifo_table['f'] = uwsgi_refork_master;
-	uwsgi_fifo_table['l'] = uwsgi_log_reopen;
-	uwsgi_fifo_table['L'] = uwsgi_log_rotate;
+	uwsgi_fifo_table['f'] = (void (*)(int))uwsgi_refork_master;
+	uwsgi_fifo_table['l'] = (void (*)(int))uwsgi_log_reopen;
+	uwsgi_fifo_table['L'] = (void (*)(int))uwsgi_log_rotate;
 	uwsgi_fifo_table['p'] = suspend_resume_them_all;
-	uwsgi_fifo_table['P'] = uwsgi_update_pidfiles;
+	uwsgi_fifo_table['P'] = (void (*)(int))uwsgi_update_pidfiles;
 	uwsgi_fifo_table['q'] = gracefully_kill_them_all;
 	uwsgi_fifo_table['Q'] = kill_them_all;
 	uwsgi_fifo_table['r'] = grace_them_all;
 	uwsgi_fifo_table['R'] = reap_them_all;
 	uwsgi_fifo_table['s'] = stats;
 	uwsgi_fifo_table['S'] = subscriptions_blocker;
-	uwsgi_fifo_table['w'] = uwsgi_reload_workers;
-	uwsgi_fifo_table['W'] = uwsgi_brutally_reload_workers;
+	uwsgi_fifo_table['w'] = (void (*)(int))uwsgi_reload_workers;
+	uwsgi_fifo_table['W'] = (void (*)(int))uwsgi_brutally_reload_workers;
 
 }
 
