@@ -72,7 +72,7 @@ void gateway_respawn(int id) {
 
 	if (gw_pid == 0) {
 		uwsgi_fixup_fds(0, 0, ug);
-		uwsgi_close_all_sockets();
+		uwsgi_close_all_unshared_sockets();
 		if (uwsgi.master_as_root)
 			uwsgi_as_root();
 #ifdef __linux__
@@ -92,6 +92,8 @@ void gateway_respawn(int id) {
 		signal(SIGSTOP, SIG_IGN);
 		signal(SIGTSTP, SIG_IGN);
 
+		uwsgi_hooks_run(uwsgi.hook_as_gateway, "as-gateway", 1);
+
 		if (ug->gid) {
 			uwsgi_log("%s %d setgid() to %d\n", ug->name, ug->num, (int) ug->gid);
 			if (setgid(ug->gid)) {
