@@ -278,6 +278,9 @@ struct uwsgi_corerouter {
 
 	size_t buffer_size;
 	int fallback_on_no_key;
+
+	char *fallback_key;
+	int fallback_key_len;
 };
 
 // a session is started when a client connect to the router
@@ -315,7 +318,7 @@ struct corerouter_session {
 #ifdef AF_INET6
 	char client_address[INET6_ADDRSTRLEN];
 #else
-	char client_address[INET_ADDRLEN];
+	char client_address[INET_ADDRSTRLEN];
 #endif
 
 	// use 11 bytes to be snprintf friendly
@@ -330,6 +333,8 @@ void uwsgi_opt_corerouter_use_pattern(char *, char *, void *);
 void uwsgi_opt_corerouter_zerg(char *, char *, void *);
 void uwsgi_opt_corerouter_cs(char *, char *, void *);
 void uwsgi_opt_corerouter_ss(char *, char *, void *);
+void uwsgi_opt_corerouter_fallback_key(char *, char *, void *);
+
 
 void corerouter_manage_subscription(char *, uint16_t, char *, uint16_t, void *);
 
