@@ -9,12 +9,12 @@ for p in search_paths:
         coroapi = p
 
 if not coroapi:
-    print "unable to find the Coro perl module !!!"
+    print("unable to find the Coro perl module !!!")
     sys.exit(1)
 
 NAME='coroae'
 CFLAGS = os.popen('perl -MExtUtils::Embed -e ccopts').read().rstrip().split()
-CFLAGS += ['-Wno-int-to-pointer-cast', '-Wno-error=int-to-pointer-cast', '-I%s/Coro' % coroapi]
+CFLAGS += ['-Wno-int-to-pointer-cast', '-Wno-error=format', '-Wno-error=int-to-pointer-cast', '-I%s/Coro' % coroapi]
 LDFLAGS = []
 LIBS = []
 
