@@ -33,7 +33,7 @@ PyObject *py_uwsgi_gevent_ctrl_gl(PyObject *self, PyObject *args) {
 	for(;;) {
 		PyObject *gevent_sleep_args = PyTuple_New(1);
                 PyTuple_SetItem(gevent_sleep_args, 0, PyInt_FromLong(60));
-                PyObject *gswitch = PyEval_CallObject(ugevent.greenlet_switch, gevent_sleep_args);
+                PyObject *gswitch = PyObject_CallObject(ugevent.greenlet_switch, gevent_sleep_args);
 		// could be NULL on exception
 		if (!gswitch) {
 			// just for being paranid
@@ -371,7 +371,7 @@ static void gil_gevent_get() {
 }
 
 static void gil_gevent_release() {
-	PyGILState_Release((PyGILState_STATE) pthread_getspecific(up.upt_gil_key));
+	PyGILState_Release((PyGILState_STATE)(long) pthread_getspecific(up.upt_gil_key));
 }
 
 static void monkey_patch() {
@@ -433,8 +433,13 @@ static void gevent_loop() {
 	ugevent.spawn = PyDict_GetItemString(gevent_dict, "spawn");
 	if (!ugevent.spawn) uwsgi_pyexit;
 
-	ugevent.signal = PyDict_GetItemString(gevent_dict, "signal");
-	if (!ugevent.signal) uwsgi_pyexit;
+	ugevent.signal = PyDict_GetItemString(gevent_dict, "signal_handler");
+	if (!ugevent.signal) {
+		// gevent.signal_handler appears in gevent 1.3.
+		// On older gevent, fall back to the deprecated gevent.signal.
+		ugevent.signal = PyDict_GetItemString(gevent_dict, "signal");
+		if (!ugevent.signal) uwsgi_pyexit;
+	}
 
 	ugevent.greenlet_switch = PyDict_GetItemString(gevent_dict, "sleep");
 	if (!ugevent.greenlet_switch) uwsgi_pyexit;
