@@ -12,34 +12,20 @@ PS_CLOSE_FUNC(uwsgi) {
 PS_READ_FUNC(uwsgi) {
 	char *cache = PS_GET_MOD_DATA();
 	uint64_t valsize = 0;
-#ifdef UWSGI_PHP7
 	char *value = uwsgi_cache_magic_get(key->val, key->len , &valsize, NULL, cache);
-#else
-	char *value = uwsgi_cache_magic_get((char *)key, strlen((char *)key), &valsize, NULL, cache);
-#endif
-        if (!value) return FAILURE;
-#ifdef UWSGI_PHP7
+	if (!value) {
+		*val = ZSTR_EMPTY_ALLOC();
+		return SUCCESS;
+	}
 	*val = zend_string_init(value, valsize, 0);
-#else
-	char *new_val = emalloc(valsize);
-	memcpy(new_val, value, valsize);
-	free(value);
-	*val = new_val;
-	*vallen = valsize;
-#endif
 	return SUCCESS;
 	
 }
 
 PS_WRITE_FUNC(uwsgi) {
 	char *cache = PS_GET_MOD_DATA();
-#ifdef UWSGI_PHP7
 	if (val->len == 0) return SUCCESS;
 	if (!uwsgi_cache_magic_set(key->val, key->len, val->val, val->len, 0, UWSGI_CACHE_FLAG_UPDATE, cache)) {
-#else
-	if (vallen == 0) return SUCCESS;
-	if (!uwsgi_cache_magic_set((char *)key, strlen(key), (char *)val, vallen, 0, UWSGI_CACHE_FLAG_UPDATE, cache)) {
-#endif
 		return SUCCESS;	
 	}
 	return FAILURE;
@@ -47,11 +33,10 @@ PS_WRITE_FUNC(uwsgi) {
 
 PS_DESTROY_FUNC(uwsgi) {
 	char *cache = PS_GET_MOD_DATA();
-#ifdef UWSGI_PHP7
+	if (!uwsgi_cache_magic_exists(key->val, key->len, cache))
+		return SUCCESS;
+
 	if (!uwsgi_cache_magic_del(key->val, key->len, cache)) {
-#else
-	if (!uwsgi_cache_magic_del((char *)key, strlen(key), cache)) {
-#endif
 		return SUCCESS;
 	}
 	return FAILURE;
