@@ -65,6 +65,8 @@ struct uwsgi_perl {
 	int shell_oneshot;
 
 	CV *spooler;
+
+	int no_plack;
 };
 
 void init_perl_embedded_module(void);
@@ -85,3 +87,5 @@ void uwsgi_perl_exec(char *);
 
 void uwsgi_perl_check_auto_reload(void);
 void uwsgi_psgi_preinit_apps(void);
+
+extern struct uwsgi_perl uperl;
