@@ -657,8 +657,13 @@ XS(XS_add_rb_timer) {
 
         uint8_t uwsgi_signal = SvIV(ST(0));
         int seconds = SvIV(ST(1));
+        int iterations = 0;
 
-        if (uwsgi_signal_add_rb_timer(uwsgi_signal, seconds, 0)) {
+        if (items > 2) {
+                iterations = SvIV(ST(2));
+        }
+
+        if (uwsgi_signal_add_rb_timer(uwsgi_signal, seconds, iterations)) {
                 croak("unable to register rb timer");
                 XSRETURN_UNDEF;
         }
@@ -883,7 +888,7 @@ XS(XS_chunked_read) {
 		XSRETURN_UNDEF;
         }
 
-	ST(0) = newSVpv(chunk, len);
+	ST(0) = newSVpvn(chunk, len);
         sv_2mortal(ST(0));
         XSRETURN(1);
 }
@@ -902,7 +907,7 @@ XS(XS_chunked_read_nb) {
                 XSRETURN_UNDEF;
         }
 
-        ST(0) = newSVpv(chunk, len);
+        ST(0) = newSVpvn(chunk, len);
         sv_2mortal(ST(0));
         XSRETURN(1);
 }
