@@ -17,6 +17,8 @@ GCC_LIST = ['rack_plugin', 'rack_api']
 if (v[0] == '1' and v[1] == '9') or v[0] >= '2':
     CFLAGS = os.popen(RUBYPATH + " -e \"require 'rbconfig';print RbConfig::CONFIG['CFLAGS']\"").read().rstrip().split()
     CFLAGS.append('-DRUBY19')
+    if version >= '2.7':
+        CFLAGS.append('-DRUBY27')
     CFLAGS.append('-Wno-unused-parameter')
     rbconfig = 'RbConfig'	 
 else:
